@@ -1,6 +1,6 @@
 package File::Map;
 {
-  $File::Map::VERSION = '0.56';
+  $File::Map::VERSION = '0.57';
 }
 
 # This software is copyright (c) 2008, 2009, 2010, 2011, 2012 by Leon Timmermans <leont@cpan.org>.
@@ -111,7 +111,7 @@ sub sys_map {    ## no critic (ProhibitManyArgs)
 
 #ABSTRACT: Memory mapping made simple and safe.
 
-
+__END__
 
 =pod
 
@@ -121,17 +121,15 @@ File::Map - Memory mapping made simple and safe.
 
 =head1 VERSION
 
-version 0.56
+version 0.57
 
 =head1 SYNOPSIS
 
  use File::Map 'map_file';
  
- map_file my $map, $filename;
- if ($map ne "foobar") {
-     $map =~ s/bar/quz/g;
-     substr $map, 1024, 11, "Hello world";
- }
+ map_file my $map, $filename, '+<';
+ $map =~ s/bar/quz/g;
+ substr $map, 1024, 11, "Hello world";
 
 =head1 DESCRIPTION
 
@@ -185,7 +183,7 @@ It has built-in support for thread synchronization.
 
 =head2 Mapping
 
-The following functions for mapping a variable are available for exportation.
+The following functions for mapping a variable are available for exportation. Note that all of these functions throw exceptions on errors, unless noted otherwise.
 
 =over 4
 
@@ -403,7 +401,9 @@ Overwriting an empty map is rather nonsensical, hence a warning is given when th
 
 This module depends on perl 5.8, L<Sub::Exporter::Progressive> and L<PerlIO::Layers>. Perl 5.8.8 or higher is recommended because older versions can give spurious warnings.
 
-On perl versions before 5.11.5 many string functions including C<substr> are limited to L<32bit logic|http://rt.perl.org/rt3//Public/Bug/Display.html?id=72784>, even on 64bit architectures. Effectively this means you can't use them on strings bigger than 2GB. If you are working with such large files, it is strongly recommended to upgrade to 5.12.
+In perl versions before 5.11.5 many string functions including C<substr> are limited to L<32bit logic|http://rt.perl.org/rt3//Public/Bug/Display.html?id=72784>, even on 64bit architectures. Effectively this means you can't use them on strings bigger than 2GB. If you are working with such large files, it is strongly recommended to upgrade to 5.12.
+
+In perl versions before 5.17.5, there is an off-by-one bug in Perl's regexp engine, as explained L<here|http://rt.perl.org/rt3//Public/Bug/Display.html?id=73542>. If the length of the file is an exact multiple of the page size, some regexps can trigger a segmentation fault.
 
 =head1 PITFALLS
 
@@ -419,8 +419,6 @@ On perl versions before 5.11.5 many string functions including C<substr> are lim
 
 =head1 BUGS AND LIMITATIONS
 
-In all perls before 5.17.5, there is an off-by-one bug in Perl's regexp engine, as explained L<here|http://rt.perl.org/rt3//Public/Bug/Display.html?id=73542>. If the length of the file is an exact multiple of the page size, some regexps can trigger a segmentation fault.
-
 As any piece of software, bugs are likely to exist here. Bug reports are welcome.
 
 Please report any bugs or feature requests to C<bug-file-map at rt.cpan.org>, or through
@@ -455,7 +453,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
